@@ -1,9 +1,10 @@
-use std::sync::{Arc, Mutex};
 use std::fmt::Debug;
+use std::sync::{Arc, Mutex};
 
 #[derive(Debug, Clone)]
 pub enum Error<PE>
-    where PE: Debug + Clone + Send + Sync + 'static,
+where
+    PE: Debug + Clone + Send + Sync + 'static,
 {
     CacheError(String),
     ProcessingError(PE),
@@ -13,9 +14,9 @@ pub enum Error<PE>
     DecodeError(String),
 }
 
-
 impl<PE> From<PE> for Error<PE>
-    where PE: Debug + Clone + Send + Sync + 'static,
+where
+    PE: Debug + Clone + Send + Sync + 'static,
 {
     fn from(err: PE) -> Self {
         Self::ProcessingError(err)
