@@ -1,15 +1,15 @@
-use tokio::sync::mpsc::{channel, Receiver, Sender};
 use log::*;
+use tokio::sync::mpsc::{channel, Receiver, Sender};
 
-use crate::event_handler::{EventHandler, OutputEvent, Completion};
-use crate::event_retriever::PayloadRetriever;
 use crate::completion_handler::CompletionHandler;
 use crate::consumer::Consumer;
+use crate::event_handler::{Completion, EventHandler, OutputEvent};
+use crate::event_retriever::PayloadRetriever;
 use std::fmt::Debug;
 
-use std::marker::PhantomData;
 use aktors::actor::Actor;
 use async_trait::async_trait;
+use std::marker::PhantomData;
 
 #[derive(Copy, Clone, Debug)]
 pub enum ProcessorState {
@@ -20,14 +20,20 @@ pub enum ProcessorState {
 
 #[derive(Clone)]
 pub struct EventProcessor<M, C, EH, Input, Output, ER, CH>
-    where
-        M: Send + Clone + Sync + 'static,
-        C: Consumer<M> + Clone + Send + Sync + 'static,
-        EH: EventHandler<InputEvent=Input, OutputEvent=Output> + Send + Sync + Clone + 'static,
-        Input: Send + Clone + 'static,
-        Output: Send + Sync + Clone + 'static,
-        ER: PayloadRetriever<Input, Message=M> + Send + Sync + Clone + 'static,
-        CH: CompletionHandler<Message=M, CompletedEvent=OutputEvent<Output, <EH as EventHandler>::Error>> + Send + Sync + Clone + 'static,
+where
+    M: Send + Clone + Sync + 'static,
+    C: Consumer<M> + Clone + Send + Sync + 'static,
+    EH: EventHandler<InputEvent = Input, OutputEvent = Output> + Send + Sync + Clone + 'static,
+    Input: Send + Clone + 'static,
+    Output: Send + Sync + Clone + 'static,
+    ER: PayloadRetriever<Input, Message = M> + Send + Sync + Clone + 'static,
+    CH: CompletionHandler<
+            Message = M,
+            CompletedEvent = OutputEvent<Output, <EH as EventHandler>::Error>,
+        > + Send
+        + Sync
+        + Clone
+        + 'static,
 {
     consumer: C,
     completion_handler: CH,
@@ -38,14 +44,20 @@ pub struct EventProcessor<M, C, EH, Input, Output, ER, CH>
 }
 
 impl<M, C, EH, Input, Output, ER, CH> EventProcessor<M, C, EH, Input, Output, ER, CH>
-    where
-        M: Send + Clone + Sync + 'static,
-        C: Consumer<M> + Clone + Send + Sync + 'static,
-        EH: EventHandler<InputEvent=Input, OutputEvent=Output> + Send + Sync + Clone + 'static,
-        Input: Send + Clone + 'static,
-        Output: Send + Sync + Clone + 'static,
-        ER: PayloadRetriever<Input, Message=M> + Send + Sync + Clone + 'static,
-        CH: CompletionHandler<Message=M, CompletedEvent=OutputEvent<Output, <EH as EventHandler>::Error>> + Send + Sync + Clone + 'static,
+where
+    M: Send + Clone + Sync + 'static,
+    C: Consumer<M> + Clone + Send + Sync + 'static,
+    EH: EventHandler<InputEvent = Input, OutputEvent = Output> + Send + Sync + Clone + 'static,
+    Input: Send + Clone + 'static,
+    Output: Send + Sync + Clone + 'static,
+    ER: PayloadRetriever<Input, Message = M> + Send + Sync + Clone + 'static,
+    CH: CompletionHandler<
+            Message = M,
+            CompletedEvent = OutputEvent<Output, <EH as EventHandler>::Error>,
+        > + Send
+        + Sync
+        + Clone
+        + 'static,
 {
     pub fn new(
         consumer: C,
@@ -65,15 +77,20 @@ impl<M, C, EH, Input, Output, ER, CH> EventProcessor<M, C, EH, Input, Output, ER
 }
 
 impl<M, C, EH, Input, Output, ER, CH> EventProcessor<M, C, EH, Input, Output, ER, CH>
-    where
-        M: Send + Clone + Sync + 'static,
-        C: Consumer<M> + Clone + Send + Sync + 'static,
-        EH: EventHandler<InputEvent=Input, OutputEvent=Output> + Send + Sync + Clone + 'static,
-        Input: Send + Clone + 'static,
-        Output: Send + Sync + Clone + 'static,
-        ER: PayloadRetriever<Input, Message=M> + Send + Sync + Clone + 'static,
-        CH: CompletionHandler<Message=M, CompletedEvent=OutputEvent<Output, <EH as EventHandler>::Error>> + Send + Sync + Clone + 'static,
-
+where
+    M: Send + Clone + Sync + 'static,
+    C: Consumer<M> + Clone + Send + Sync + 'static,
+    EH: EventHandler<InputEvent = Input, OutputEvent = Output> + Send + Sync + Clone + 'static,
+    Input: Send + Clone + 'static,
+    Output: Send + Sync + Clone + 'static,
+    ER: PayloadRetriever<Input, Message = M> + Send + Sync + Clone + 'static,
+    CH: CompletionHandler<
+            Message = M,
+            CompletedEvent = OutputEvent<Output, <EH as EventHandler>::Error>,
+        > + Send
+        + Sync
+        + Clone
+        + 'static,
 {
     pub async fn process_event(&mut self, event: M) {
         // TODO: Handle errors
@@ -82,7 +99,7 @@ impl<M, C, EH, Input, Output, ER, CH> EventProcessor<M, C, EH, Input, Output, ER
             Ok(retrieved_event) => {
                 info!("Retrieved event");
                 Some(retrieved_event)
-            },
+            }
             Err(e) => {
                 warn!("Failed to retrieve event with: {:?}", e);
                 None
@@ -94,14 +111,21 @@ impl<M, C, EH, Input, Output, ER, CH> EventProcessor<M, C, EH, Input, Output, ER
         if let Some(retrieved_event) = retrieved_event {
             info!("Handling retrieved event");
             let output_event = self.event_handler.handle_event(retrieved_event).await;
-            self.completion_handler.mark_complete(event, output_event).await;
+            self.completion_handler
+                .mark_complete(event, output_event)
+                .await;
         }
 
         info!("self.processor_state {:?}", self.state);
         if let ProcessorState::Started = self.state {
             info!("Getting next event");
             self.consumer
-                .get_next_event(self.self_actor.clone().expect("event_processor, self_actor")).await;
+                .get_next_event(
+                    self.self_actor
+                        .clone()
+                        .expect("event_processor, self_actor"),
+                )
+                .await;
         }
     }
 
@@ -110,7 +134,8 @@ impl<M, C, EH, Input, Output, ER, CH> EventProcessor<M, C, EH, Input, Output, ER
 
         info!("Getting next event from consumer");
         self.consumer
-            .get_next_event(self.self_actor.clone().unwrap()).await;
+            .get_next_event(self.self_actor.clone().unwrap())
+            .await;
     }
 
     pub fn stop_processing(&mut self) {
@@ -121,18 +146,18 @@ impl<M, C, EH, Input, Output, ER, CH> EventProcessor<M, C, EH, Input, Output, ER
 
 #[allow(non_camel_case_types)]
 pub enum EventProcessorMessage<M>
-    where
-        M: Send + Clone + Sync + 'static,
+where
+    M: Send + Clone + Sync + 'static,
 {
     process_event { event: M },
     start_processing {},
     stop_processing {},
-    release
+    release,
 }
 
 impl<M> aktors::actor::Message for EventProcessorMessage<M>
-    where
-        M: Send + Clone + Sync + 'static,
+where
+    M: Send + Clone + Sync + 'static,
 {
     fn is_release(&self) -> bool {
         if let Self::release = self {
@@ -144,22 +169,29 @@ impl<M> aktors::actor::Message for EventProcessorMessage<M>
 }
 
 #[async_trait]
-impl<M, C, EH, Input, Output, ER, CH> Actor<EventProcessorMessage<M>> for EventProcessor<M, C, EH, Input, Output, ER, CH>
-    where
-        M: Send + Clone + Sync + 'static,
-        C: Consumer<M> + Clone + Send + Sync + 'static,
-        EH: EventHandler<InputEvent=Input, OutputEvent=Output> + Send + Sync + Clone + 'static,
-        Input: Send + Clone + 'static,
-        Output: Send + Sync + Clone + 'static,
-        ER: PayloadRetriever<Input, Message=M> + Send + Sync + Clone + 'static,
-        CH: CompletionHandler<Message=M, CompletedEvent=OutputEvent<Output, <EH as EventHandler>::Error>> + Send + Sync + Clone + 'static,
+impl<M, C, EH, Input, Output, ER, CH> Actor<EventProcessorMessage<M>>
+    for EventProcessor<M, C, EH, Input, Output, ER, CH>
+where
+    M: Send + Clone + Sync + 'static,
+    C: Consumer<M> + Clone + Send + Sync + 'static,
+    EH: EventHandler<InputEvent = Input, OutputEvent = Output> + Send + Sync + Clone + 'static,
+    Input: Send + Clone + 'static,
+    Output: Send + Sync + Clone + 'static,
+    ER: PayloadRetriever<Input, Message = M> + Send + Sync + Clone + 'static,
+    CH: CompletionHandler<
+            Message = M,
+            CompletedEvent = OutputEvent<Output, <EH as EventHandler>::Error>,
+        > + Send
+        + Sync
+        + Clone
+        + 'static,
 {
     async fn route_message(&mut self, msg: EventProcessorMessage<M>) {
         match msg {
             EventProcessorMessage::process_event { event } => self.process_event(event).await,
             EventProcessorMessage::start_processing {} => self.start_processing().await,
             EventProcessorMessage::stop_processing {} => self.stop_processing(),
-            EventProcessorMessage::release => ()
+            EventProcessorMessage::release => (),
         };
     }
 
@@ -173,8 +205,8 @@ impl<M, C, EH, Input, Output, ER, CH> Actor<EventProcessorMessage<M>> for EventP
 }
 
 pub struct EventProcessorActor<M>
-    where
-        M: Send + Clone + Sync + 'static,
+where
+    M: Send + Clone + Sync + 'static,
 {
     sender: Sender<EventProcessorMessage<M>>,
     inner_rc: std::sync::Arc<std::sync::atomic::AtomicUsize>,
@@ -185,11 +217,13 @@ pub struct EventProcessorActor<M>
 }
 
 impl<M> Clone for EventProcessorActor<M>
-    where
-        M: Send + Clone + Sync + 'static,
+where
+    M: Send + Clone + Sync + 'static,
 {
     fn clone(&self) -> Self {
-        self.inner_rc.clone().fetch_add(1, std::sync::atomic::Ordering::SeqCst);
+        self.inner_rc
+            .clone()
+            .fetch_add(1, std::sync::atomic::Ordering::SeqCst);
 
         Self {
             sender: self.sender.clone(),
@@ -208,29 +242,32 @@ impl<M> Clone for EventProcessorActor<M>
 }
 
 impl<M> EventProcessorActor<M>
-    where
-        M: Send + Clone + Sync + 'static,
+where
+    M: Send + Clone + Sync + 'static,
 {
-    pub fn new<C, EH, Input, Output, ER, CH>(mut actor_impl: EventProcessor<M, C, EH, Input, Output, ER, CH>) -> (Self, tokio::task::JoinHandle<()>)
-        where
-            C: Consumer<M> + Clone + Send + Sync + 'static,
-            EH: EventHandler<InputEvent=Input, OutputEvent=Output> + Send + Sync + Clone + 'static,
-            Input: Send + Clone + 'static,
-            Output: Send + Sync + Clone + 'static,
-            ER: PayloadRetriever<Input, Message=M> + Send + Sync + Clone + 'static,
-            CH: CompletionHandler<Message=M, CompletedEvent=OutputEvent<Output, <EH as EventHandler>::Error>> + Send + Sync + Clone + 'static,
+    pub fn new<C, EH, Input, Output, ER, CH>(
+        mut actor_impl: EventProcessor<M, C, EH, Input, Output, ER, CH>,
+    ) -> (Self, tokio::task::JoinHandle<()>)
+    where
+        C: Consumer<M> + Clone + Send + Sync + 'static,
+        EH: EventHandler<InputEvent = Input, OutputEvent = Output> + Send + Sync + Clone + 'static,
+        Input: Send + Clone + 'static,
+        Output: Send + Sync + Clone + 'static,
+        ER: PayloadRetriever<Input, Message = M> + Send + Sync + Clone + 'static,
+        CH: CompletionHandler<
+                Message = M,
+                CompletedEvent = OutputEvent<Output, <EH as EventHandler>::Error>,
+            > + Send
+            + Sync
+            + Clone
+            + 'static,
     {
         let (sender, receiver) = channel(1);
         let inner_rc = std::sync::Arc::new(std::sync::atomic::AtomicUsize::new(1));
         let queue_len = std::sync::Arc::new(std::sync::atomic::AtomicUsize::new(0));
 
         let actor_uuid = uuid::Uuid::new_v4();
-        let actor_name = format!(
-            "{} {} {}",
-            stringify!(EventProcessor),
-            actor_uuid,
-            0,
-        );
+        let actor_name = format!("{} {} {}", stringify!(EventProcessor), actor_uuid, 0,);
         let inner_actor = Self {
             sender,
             inner_rc: inner_rc.clone(),
@@ -244,16 +281,9 @@ impl<M> EventProcessorActor<M>
 
         actor_impl.self_actor = Some(inner_actor);
 
-        let handle = tokio::task::spawn(
-            aktors::actor::route_wrapper(
-                aktors::actor::Router::new(
-                    actor_impl,
-                    receiver,
-                    inner_rc,
-                    queue_len
-                )
-            )
-        );
+        let handle = tokio::task::spawn(aktors::actor::route_wrapper(aktors::actor::Router::new(
+            actor_impl, receiver, inner_rc, queue_len,
+        )));
 
         (self_actor, handle)
     }
@@ -266,11 +296,9 @@ impl<M> EventProcessorActor<M>
         let queue_len = self.queue_len.clone();
         queue_len.fetch_add(1, std::sync::atomic::Ordering::SeqCst);
 
-        tokio::task::spawn(
-            async move {
-                sender.send(msg).await;
-            }
-        );
+        tokio::task::spawn(async move {
+            sender.send(msg).await;
+        });
     }
 
     pub async fn process_event(&self, event: M) {
@@ -281,19 +309,17 @@ impl<M> EventProcessorActor<M>
         let queue_len = self.queue_len.clone();
         queue_len.fetch_add(1, std::sync::atomic::Ordering::SeqCst);
 
-        tokio::task::spawn(
-            async move {
-                if let Err(e) = sender.send(msg).await {
-                    panic!(
-                        concat!(
-                            "Receiver has failed with {}, propagating error. ",
-                            "EventProcessorActor.process_event"
-                        ),
-                        e
-                    )
-                }
+        tokio::task::spawn(async move {
+            if let Err(e) = sender.send(msg).await {
+                panic!(
+                    concat!(
+                        "Receiver has failed with {}, propagating error. ",
+                        "EventProcessorActor.process_event"
+                    ),
+                    e
+                )
             }
-        );
+        });
     }
 
     pub async fn start_processing(&self) {
@@ -304,19 +330,17 @@ impl<M> EventProcessorActor<M>
         let queue_len = self.queue_len.clone();
         queue_len.fetch_add(1, std::sync::atomic::Ordering::SeqCst);
 
-        tokio::task::spawn(
-            async move {
-                if let Err(e) = sender.send(msg).await {
-                    panic!(
-                        concat!(
-                            "Receiver has failed with {}, propagating error. ",
-                            "EventProcessorActor.start_processing"
-                        ),
-                        e
-                    )
-                }
+        tokio::task::spawn(async move {
+            if let Err(e) = sender.send(msg).await {
+                panic!(
+                    concat!(
+                        "Receiver has failed with {}, propagating error. ",
+                        "EventProcessorActor.start_processing"
+                    ),
+                    e
+                )
             }
-        );
+        });
     }
 
     pub async fn stop_processing(&self) {
@@ -327,27 +351,27 @@ impl<M> EventProcessorActor<M>
         let queue_len = self.queue_len.clone();
 
         queue_len.fetch_add(1, std::sync::atomic::Ordering::SeqCst);
-        tokio::task::spawn(
-            async move {
-                if let Err(e) = sender.send(msg).await {
-                    panic!(
-                        concat!(
-                            "Receiver has failed with {}, propagating error. ",
-                            "EventProcessorActor.stop_processing"
-                        ),
-                        e
-                    )
-                }
+        tokio::task::spawn(async move {
+            if let Err(e) = sender.send(msg).await {
+                panic!(
+                    concat!(
+                        "Receiver has failed with {}, propagating error. ",
+                        "EventProcessorActor.stop_processing"
+                    ),
+                    e
+                )
             }
-        );
+        });
     }
 }
 
 impl<M> Drop for EventProcessorActor<M>
-    where
-        M: Send + Clone + Sync + 'static,
+where
+    M: Send + Clone + Sync + 'static,
 {
     fn drop(&mut self) {
-        self.inner_rc.clone().fetch_sub(1, std::sync::atomic::Ordering::SeqCst);
+        self.inner_rc
+            .clone()
+            .fetch_sub(1, std::sync::atomic::Ordering::SeqCst);
     }
 }
