@@ -21,12 +21,12 @@ pub trait PayloadRetriever<T> {
     async fn retrieve_event(&mut self, msg: &Self::Message) -> Result<T, Box<dyn Error>>;
 }
 
-
 #[derive(Clone)]
 pub struct S3PayloadRetriever<S, D, E>
-    where S: S3 + Clone + Send + Sync + 'static,
-          D: PayloadDecoder<E> + Clone + Send + 'static,
-          E: Send + 'static
+where
+    S: S3 + Clone + Send + Sync + 'static,
+    D: PayloadDecoder<E> + Clone + Send + 'static,
+    E: Send + 'static,
 {
     s3: S,
     decoder: D,
@@ -34,20 +34,26 @@ pub struct S3PayloadRetriever<S, D, E>
 }
 
 impl<S, D, E> S3PayloadRetriever<S, D, E>
-    where S: S3 + Clone + Send + Sync + 'static,
-          D: PayloadDecoder<E> + Clone + Send + 'static,
-          E: Send + 'static
+where
+    S: S3 + Clone + Send + Sync + 'static,
+    D: PayloadDecoder<E> + Clone + Send + 'static,
+    E: Send + 'static,
 {
     pub fn new(s3: S, decoder: D) -> Self {
-        Self { s3, decoder, phantom: PhantomData }
+        Self {
+            s3,
+            decoder,
+            phantom: PhantomData,
+        }
     }
 }
 
 #[async_trait]
 impl<S, D, E> PayloadRetriever<E> for S3PayloadRetriever<S, D, E>
-    where S: S3 + Clone + Send + Sync + 'static,
-          D: PayloadDecoder<E> + Clone + Send + 'static,
-          E: Send + 'static
+where
+    S: S3 + Clone + Send + Sync + 'static,
+    D: PayloadDecoder<E> + Clone + Send + 'static,
+    E: Send + 'static,
 {
     type Message = SqsMessage;
     async fn retrieve_event(&mut self, msg: &Self::Message) -> Result<E, Box<dyn Error>> {
@@ -63,18 +69,13 @@ impl<S, D, E> PayloadRetriever<E> for S3PayloadRetriever<S, D, E>
 
         println!("{}/{}", bucket, key);
 
-        let s3_data = self.s3.get_object(
-            GetObjectRequest {
-                bucket: bucket.to_string(),
-                key: key.to_string(),
-                ..Default::default()
-            }
-        );
+        let s3_data = self.s3.get_object(GetObjectRequest {
+            bucket: bucket.to_string(),
+            key: key.to_string(),
+            ..Default::default()
+        });
 
-        let s3_data = tokio::time::timeout(
-            Duration::from_secs(5),
-            s3_data,
-        ).await??;
+        let s3_data = tokio::time::timeout(Duration::from_secs(5), s3_data).await??;
         // .with_timeout(Duration::from_secs(2)).compat().await?;
 
         let object_size = record["object"]["size"].as_u64().unwrap_or_default();
@@ -88,10 +89,14 @@ impl<S, D, E> PayloadRetriever<E> for S3PayloadRetriever<S, D, E>
 
         let mut body = Vec::with_capacity(prealloc);
 
-        s3_data.body.expect("Missing S3 body").into_async_read().read_to_end(&mut body).await?;
+        s3_data
+            .body
+            .expect("Missing S3 body")
+            .into_async_read()
+            .read_to_end(&mut body)
+            .await?;
 
         info!("Read s3 payload body");
         self.decoder.decode(body)
     }
 }
-
