@@ -9,7 +9,7 @@ use log::warn;
 
 use async_trait::async_trait;
 
-use crate::cache::{Cache, Cacheable, CacheResponse};
+use crate::cache::{Cache, CacheResponse, Cacheable};
 
 #[derive(Clone)]
 pub struct RedisCache {
@@ -19,39 +19,31 @@ pub struct RedisCache {
 
 impl RedisCache {
     pub async fn new(address: String) -> Result<Self, RedisError> {
-        let connection_pool = ConnectionPool::create(
-            address.clone(),
-            None,
-            num_cpus::get(),
-        ).await?;
+        let connection_pool =
+            ConnectionPool::create(address.clone(), None, num_cpus::get()).await?;
 
-        Ok(
-            Self {
-                connection_pool,
-                address,
-            }
-        )
+        Ok(Self {
+            connection_pool,
+            address,
+        })
     }
 }
 
 #[async_trait]
 impl<E> Cache<E> for RedisCache
-    where
-        E: Debug + Clone + Send + Sync + 'static,
+where
+    E: Debug + Clone + Send + Sync + 'static,
 {
     async fn get<CA>(&mut self, cacheable: CA) -> Result<CacheResponse, crate::error::Error<E>>
-        where
-            CA: Cacheable + Send + Sync + 'static,
+    where
+        CA: Cacheable + Send + Sync + 'static,
     {
         let identity = cacheable.identity();
         let identity = hex::encode(identity);
-//
+        //
         let mut client = self.connection_pool.get().await;
 
-        let res = tokio::time::timeout(
-            Duration::from_millis(200),
-            client.exists(&identity),
-        ).await;
+        let res = tokio::time::timeout(Duration::from_millis(200), client.exists(&identity)).await;
 
         let res = match res {
             Ok(res) => res,
@@ -71,8 +63,7 @@ impl<E> Cache<E> for RedisCache
         }
     }
 
-    async fn store(&mut self, identity: Vec<u8>) -> Result<(), crate::error::Error<E>>
-    {
+    async fn store(&mut self, identity: Vec<u8>) -> Result<(), crate::error::Error<E>> {
         let identity = hex::encode(identity);
 
         let mut client = self.connection_pool.get().await;
@@ -80,13 +71,12 @@ impl<E> Cache<E> for RedisCache
         let res = tokio::time::timeout(
             Duration::from_millis(200),
             client.set_and_expire_seconds(&identity, b"1", 16 * 60),
-        ).await;
+        )
+        .await;
 
-        res
-            .map_err(|err| crate::error::Error::CacheError(format!("{}", err)))?
+        res.map_err(|err| crate::error::Error::CacheError(format!("{}", err)))?
             .map_err(|err| crate::error::Error::CacheError(format!("{}", err)))?;
 
-
         Ok(())
     }
-}
\ No newline at end of file
+}
